@@ -7,10 +7,13 @@ import sys
 import traceback
 import uuid
 import gc
+import logging
 import gevent
 import gevent.pywsgi
+import gevent.util
 import socketio
 from engineio import static_files
+from gevent._greenlet_primitives import get_reachable_greenlets
 
 from suanpan import asyncio, error, g, runtime, utils
 from suanpan.arguments import Bool, BoolOrInt, Float, Int, String
@@ -115,8 +118,8 @@ class Stream(
             logger.debug(f"Loaded params: {params}")
             return params
         except Exception:  # pylint: disable=broad-except
-            tracebackInfo = traceback.format_exc()
-            logger.debug(f"Load params error: {tracebackInfo}")
+            # tracebackInfo = traceback.format_exc()
+            # logger.debug(f"Load params error: {tracebackInfo}")
             return {}
 
     def saveParams(self, params):
@@ -157,9 +160,18 @@ class Stream(
         logger.debug("Stream ALL Loop Closed")
 
         if self._exit_code != 0:
+            logging.shutdown()
+            # gevent.util.print_run_info()
+
+            # glets = get_reachable_greenlets()
+            # running = []
+            # for ob in glets:
+            #     if isinstance(ob, gevent.Greenlet) and bool(ob):
+            #         running.append(ob)
+
             # kill greenlet created by other modules
-            running = [obj for obj in gc.get_objects() if isinstance(obj, gevent.Greenlet) and bool(obj)]
-            gevent.killall(running)
+            # running = [obj for obj in gc.get_objects() if isinstance(obj, gevent.Greenlet) and bool(obj)]
+            # gevent.killall(running)
             sys.exit(self._exit_code)
 
     def close(self, code=0):
@@ -379,7 +391,7 @@ class StreamTriggerLoop(StreamMQBaseLoop):
 class StreamSIOLoop(StreamBaseLoop):
     DEFAULT_HANDLER_CLASS = handlers.SIOHandler
     EVENT_CONNECT = "connect"
-    EXTRA_CONTEXT_TYPES = {"mjs": "text/javascript"}
+    EXTRA_CONTEXT_TYPES = {"mjs": "text/javascript", "svg": "image/svg+xml"}
 
     def __init__(self, stream):
         super().__init__(stream)
